<?php

namespace Hrm\Resignation\Policies;

use Litepie\User\Contracts\UserPolicy;
use Hrm\Resignation\Models\Resignation;

class ResignationPolicy
{

    /**
     * Determine if the given user can view the resignation.
     *
     * @param UserPolicy $user
     * @param Resignation $resignation
     *
     * @return bool
     */
    public function view(UserPolicy $user, Resignation $resignation)
    {
        if ($user->canDo('resignation.resignation.view') && $user->isAdmin()) {
            return true;
        }

        return $resignation->user_id == user_id() && $resignation->user_type == user_type();
    }

    /**
     * Determine if the given user can create a resignation.
     *
     * @param UserPolicy $user
     * @param Resignation $resignation
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('resignation.resignation.create');
    }

    /**
     * Determine if the given user can update the given resignation.
     *
     * @param UserPolicy $user
     * @param Resignation $resignation
     *
     * @return bool
     */
    public function update(UserPolicy $user, Resignation $resignation)
    {
        if ($user->canDo('resignation.resignation.edit') && $user->isAdmin()) {
            return true;
        }

        return $resignation->user_id == user_id() && $resignation->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given resignation.
     *
     * @param UserPolicy $user
     * @param Resignation $resignation
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Resignation $resignation)
    {
        return $resignation->user_id == user_id() && $resignation->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given resignation.
     *
     * @param UserPolicy $user
     * @param Resignation $resignation
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Resignation $resignation)
    {
        if ($user->canDo('resignation.resignation.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given resignation.
     *
     * @param UserPolicy $user
     * @param Resignation $resignation
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Resignation $resignation)
    {
        if ($user->canDo('resignation.resignation.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
